@@ -7,7 +7,7 @@
 create_beast2_tracelog_folder <- function(beast2_options) {
   # Extract the tracelog file
   testthat::expect_true(file.exists(beast2_options$input_filename))
-  tracelog_filename <- beastier::extract_tracelog_filename_from_beast2_input_file(
+  tracelog_filename <- beastier::extract_tracelog_filename_from_beast2_input_file( # nolint indeed a long line
     input_filename = beast2_options$input_filename
   )
   dir.create(
