@@ -12,5 +12,5 @@
 #' @export
 remove_beaustier_folders <- function() {
   beastier::remove_beastier_folder()
-  beastier::remove_beautier_folder()
+  beautier::remove_beautier_folder()
 }
